@@ -17,7 +17,8 @@ if __name__ == "__main__":
     f = 0.1
     n = [0, 0, 0, 0, 1, 0, 0, 0, 0]
     problem = StaticProblem(sq_array, frustration=f, vortex_configuration=n)
-    config, _, _ = problem.compute()
+    config, _, info = problem.compute()
+    print(info)
     handles = config.plot()
     plt.show()
 
@@ -25,3 +26,5 @@ if __name__ == "__main__":
 
 
 
+
+
