@@ -15,7 +15,7 @@ if __name__ == "__main__":
     N = 14
     array = SquareArray(N, N)
 
-    Llist = [0.001, 0.1, 1, 10]
+    Llist = [0.001, 0.1, 1, 5]
 
     f = 1 / (N - 1) ** 2  # frustration
     n = np.zeros(array.face_count(), dtype=int)  # target vortex configuration
@@ -24,8 +24,8 @@ if __name__ == "__main__":
     for i, L in enumerate(Llist):
         array.set_inductance_factors(L)
         prob = StaticProblem(array, frustration=f, vortex_configuration=n)
-        out, _,info = prob.compute()
-        out.plot(show_face_quantity=True, face_quantity="flux", face_quantity_logarithmic_colors=True,
+        out, _, info = prob.compute()
+        out.plot(face_quantity="flux", face_quantity_logarithmic_colors=True,
                  face_quantity_clim=[1E-3, 1], title=f"beta_L={L}", arrow_color=[1, 1, 1])
 
 
